/*
* phone.c - example of phone for media volume control.
* This file is part of PetrSU KP Library.
*
* Copyright (C) 2009 - Vanag Pavel. All rights reserved.
*
* PetrSU KP Library is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* PetrSU KP Library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with PetrSU KP Library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor,
* Boston, MA  02110-1301  USA
*/

#include "../SmartSlog_lib/media.h"

/* Print menu for user */
static void print_menu()
{
	printf("\n--- Menu ---");
	printf("\n1 - Call incoming.");
	printf("\n2 - Call ends.");
	printf("\n0 - Exit.\n");
}

/* Removes all triples from thr smart space */
static void clean_ss()
{
	printf("\n\n --- Clean ---\n");

	ss_triple_t *triples = NULL;
	ss_add_triple(&triples, SS_RDF_SIB_ANY, SS_RDF_SIB_ANY, SS_RDF_SIB_ANY, SS_RDF_TYPE_URI, SS_RDF_TYPE_URI);

	ss_remove(sslog_get_ss_info(), triples);
	ss_delete_triples(triples);
}

int main()
{
	//sslog_ss_init_session();
	sslog_ss_init_session_with_parameters("X", "192.168.112.108", 10010);
	register_ontology();

	if (ss_join(sslog_get_ss_info(), "Phone KP") == -1) {
		printf("Can't join to SS\n");
		return 0;
	}

	individual_t *phone = sslog_new_individual(CLASS_MOBILEPHONE);

	if (phone == NULL) {
		printf("\nError: %s\n", get_error_text());
		return 0;
	}


    sslog_ss_init_individual_with_uuid(phone, "phone1");

	char *calling = (char *) malloc(sizeof(char) * 2);
	calling[0] = '0';
	calling[1] = '\0';
	sslog_add_property(phone, PROPERTY_ISCALLING, calling);

	while (true) {
		print_menu();

		char c = getc(stdin);

		if (c == '0') {
			break;
		} else if (c == '1') {

			char *old_val = strdup(calling);
			calling[0] = '1';

			if (sslog_ss_update_property(phone, PROPERTY_ISCALLING->name, old_val, calling) < 0)
				printf("Values coudn't updated\n");
			free(old_val);

		} else if (c == '2') {

			char *old_val = strdup(calling);
			calling[0] = '0';

			if (sslog_ss_update_property(phone, PROPERTY_ISCALLING->name, old_val, calling) < 0)
				printf("Values coudn't updated\n");
			free(old_val);
		}
	}

    clean_ss();

	free(calling);

	ss_leave(sslog_get_ss_info());
	sslog_ss_leave_session_all();
	sslog_repo_clean_all();

	printf("\nKP leave SS...\n");

	return 0;
}
